==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/LoT/AwsIoTAnalyticsPipeline.md <==
# AwsIoTAnalyticsPipeline


```text
aws-20210730/Resource/LoT/AwsIoTAnalyticsPipeline
```

```text
include('aws-20210730/Resource/LoT/AwsIoTAnalyticsPipeline')
```



| Illustration | AwsIoTAnalyticsPipeline | AwsIoTAnalyticsPipelineCard | AwsIoTAnalyticsPipelineGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/LoT/AwsIoTAnalyticsPipeline.png) | ![illustration for AwsIoTAnalyticsPipeline](../../../aws-20210730/Resource/LoT/AwsIoTAnalyticsPipeline.Local.png) | ![illustration for AwsIoTAnalyticsPipelineCard](../../../aws-20210730/Resource/LoT/AwsIoTAnalyticsPipelineCard.Local.png) | ![illustration for AwsIoTAnalyticsPipelineGroup](../../../aws-20210730/Resource/LoT/AwsIoTAnalyticsPipelineGroup.Local.png) |




## AwsIoTAnalyticsPipeline

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsPipeline
include('aws-20210730/Resource/LoT/AwsIoTAnalyticsPipeline')

' renders the element
AwsIoTAnalyticsPipeline('AwsIoTAnalyticsPipeline', 'Aws Io T Analytics Pipeline', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsPipeline
include('aws-20210730/Resource/LoT/AwsIoTAnalyticsPipeline')

' renders the element
AwsIoTAnalyticsPipeline('AwsIoTAnalyticsPipeline', 'Aws Io T Analytics Pipeline', 'an optional tech label')
@enduml
```

## AwsIoTAnalyticsPipelineCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsPipelineCard
include('aws-20210730/Resource/LoT/AwsIoTAnalyticsPipeline')

' renders the element
AwsIoTAnalyticsPipelineCard('AwsIoTAnalyticsPipelineCard', 'Aws Io T Analytics Pipeline Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsPipelineCard
include('aws-20210730/Resource/LoT/AwsIoTAnalyticsPipeline')

' renders the element
AwsIoTAnalyticsPipelineCard('AwsIoTAnalyticsPipelineCard', 'Aws Io T Analytics Pipeline Card', 'an optional description')
@enduml
```

## AwsIoTAnalyticsPipelineGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsPipelineGroup
include('aws-20210730/Resource/LoT/AwsIoTAnalyticsPipeline')

' renders the element
AwsIoTAnalyticsPipelineGroup('AwsIoTAnalyticsPipelineGroup', 'Aws Io T Analytics Pipeline Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsPipelineGroup
include('aws-20210730/Resource/LoT/AwsIoTAnalyticsPipeline')

' renders the element
AwsIoTAnalyticsPipelineGroup('AwsIoTAnalyticsPipelineGroup', 'Aws Io T Analytics Pipeline Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/LoT/AwsIoTAnalyticsPipeline.md <==
# AwsIoTAnalyticsPipeline


```text
aws-20210730/Resource/LoT/AwsIoTAnalyticsPipeline
```

```text
include('aws-20210730/Resource/LoT/AwsIoTAnalyticsPipeline')
```



| Illustration | AwsIoTAnalyticsPipeline | AwsIoTAnalyticsPipelineCard | AwsIoTAnalyticsPipelineGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/LoT/AwsIoTAnalyticsPipeline.png) | ![illustration for AwsIoTAnalyticsPipeline](../../../aws-20210730/Resource/LoT/AwsIoTAnalyticsPipeline.Local.png) | ![illustration for AwsIoTAnalyticsPipelineCard](../../../aws-20210730/Resource/LoT/AwsIoTAnalyticsPipelineCard.Local.png) | ![illustration for AwsIoTAnalyticsPipelineGroup](../../../aws-20210730/Resource/LoT/AwsIoTAnalyticsPipelineGroup.Local.png) |




## AwsIoTAnalyticsPipeline

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsPipeline
include('aws-20210730/Resource/LoT/AwsIoTAnalyticsPipeline')

' renders the element
AwsIoTAnalyticsPipeline('AwsIoTAnalyticsPipeline', 'Aws Io T Analytics Pipeline', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsPipeline
include('aws-20210730/Resource/LoT/AwsIoTAnalyticsPipeline')

' renders the element
AwsIoTAnalyticsPipeline('AwsIoTAnalyticsPipeline', 'Aws Io T Analytics Pipeline', 'an optional tech label')
@enduml
```

## AwsIoTAnalyticsPipelineCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsPipelineCard
include('aws-20210730/Resource/LoT/AwsIoTAnalyticsPipeline')

' renders the element
AwsIoTAnalyticsPipelineCard('AwsIoTAnalyticsPipelineCard', 'Aws Io T Analytics Pipeline Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsPipelineCard
include('aws-20210730/Resource/LoT/AwsIoTAnalyticsPipeline')

' renders the element
AwsIoTAnalyticsPipelineCard('AwsIoTAnalyticsPipelineCard', 'Aws Io T Analytics Pipeline Card', 'an optional description')
@enduml
```

## AwsIoTAnalyticsPipelineGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsPipelineGroup
include('aws-20210730/Resource/LoT/AwsIoTAnalyticsPipeline')

' renders the element
AwsIoTAnalyticsPipelineGroup('AwsIoTAnalyticsPipelineGroup', 'Aws Io T Analytics Pipeline Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsPipelineGroup
include('aws-20210730/Resource/LoT/AwsIoTAnalyticsPipeline')

' renders the element
AwsIoTAnalyticsPipelineGroup('AwsIoTAnalyticsPipelineGroup', 'Aws Io T Analytics Pipeline Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
